@@ -1,5 +1,5 @@
 
-lambdaSelection <- function(obj, criterion=c("PC", "AGNES", "A-MSE", "VUL", "STARS", "AIC", "BIC"), ...)
+lambdaSelection <- function(obj, criterion=c("PC", "AGNES", "A-MSE", "VUL", "STARS", "AIC", "BIC", "eBIC"), ...)
 {
   if(class(obj) != "huge" & class(obj) != "tiger" & class(obj) != "wfgl")
     stop("object has to be of class huge, tiger or wfgl")
@@ -9,7 +9,7 @@ lambdaSelection <- function(obj, criterion=c("PC", "AGNES", "A-MSE", "VUL", "STA
   if(length(obj$lambda) < 5)
     stop("lambda sequence has to be of length 5 or higher")
   
-  pcriterion <- c("PC","AGNES","A-MSE","STARS","VUL", "BIC", "AIC")
+  pcriterion <- c("PC","AGNES","A-MSE","STARS","VUL", "BIC", "AIC", "eBIC")
    if(length(criterion ) > 1)
     warning("criterion attribute length is larger than one. Only the first component will be used")
  
@@ -27,7 +27,7 @@ lambdaSelection <- function(obj, criterion=c("PC", "AGNES", "A-MSE", "VUL", "STA
     ret.list <- huge.select(obj, criterion = "stars", ...)
   if(criterion[1] == "VUL")
     ret.list <- vulLambdaSelection(obj, ...)
-  if(criterion[1] == "AIC"|criterion[1] == "BIC")
+  if(criterion[1] == "AIC"|criterion[1] == "BIC"|criterion[1] == "eBIC")
     ret.list <- aicAndbicLambdaSelection(obj, criterion = criterion[1], ...)
   return(ret.list)
 }
\ No newline at end of file
